==> open-cluster-management-cluster-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1beta1/ManagedClusterSetBindingBuilder.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ManagedClusterSetBindingBuilder extends ManagedClusterSetBindingFluentImpl<ManagedClusterSetBindingBuilder> implements VisitableBuilder<ManagedClusterSetBinding,ManagedClusterSetBindingBuilder>{
  public ManagedClusterSetBindingBuilder() {
    this(false);
  }
  public ManagedClusterSetBindingBuilder(Boolean validationEnabled) {
    this(new ManagedClusterSetBinding(), validationEnabled);
  }
  public ManagedClusterSetBindingBuilder(ManagedClusterSetBindingFluent<?> fluent) {
    this(fluent, false);
  }
  public ManagedClusterSetBindingBuilder(ManagedClusterSetBindingFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ManagedClusterSetBinding(), validationEnabled);
  }
  public ManagedClusterSetBindingBuilder(ManagedClusterSetBindingFluent<?> fluent,ManagedClusterSetBinding instance) {
    this(fluent, instance, false);
  }
  public ManagedClusterSetBindingBuilder(ManagedClusterSetBindingFluent<?> fluent,ManagedClusterSetBinding instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ManagedClusterSetBindingBuilder(ManagedClusterSetBinding instance) {
    this(instance,false);
  }
  public ManagedClusterSetBindingBuilder(ManagedClusterSetBinding instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
    }
    this.validationEnabled = validationEnabled; 
  }
  ManagedClusterSetBindingFluent<?> fluent;
  Boolean validationEnabled;
  public ManagedClusterSetBinding build() {
    ManagedClusterSetBinding buildable = new ManagedClusterSetBinding(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    return buildable;
  }
  
}

==> open-cluster-management-cluster-model-6.8.1-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1beta1/ManagedClusterSetBindingBuilder.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ManagedClusterSetBindingBuilder extends ManagedClusterSetBindingFluent<ManagedClusterSetBindingBuilder> implements VisitableBuilder<ManagedClusterSetBinding,ManagedClusterSetBindingBuilder>{
  public ManagedClusterSetBindingBuilder() {
    this(false);
  }
  public ManagedClusterSetBindingBuilder(Boolean validationEnabled) {
    this(new ManagedClusterSetBinding(), validationEnabled);
  }
  public ManagedClusterSetBindingBuilder(ManagedClusterSetBindingFluent<?> fluent) {
    this(fluent, false);
  }
  public ManagedClusterSetBindingBuilder(ManagedClusterSetBindingFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ManagedClusterSetBinding(), validationEnabled);
  }
  public ManagedClusterSetBindingBuilder(ManagedClusterSetBindingFluent<?> fluent,ManagedClusterSetBinding instance) {
    this(fluent, instance, false);
  }
  public ManagedClusterSetBindingBuilder(ManagedClusterSetBindingFluent<?> fluent,ManagedClusterSetBinding instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ManagedClusterSetBinding());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ManagedClusterSetBindingBuilder(ManagedClusterSetBinding instance) {
    this(instance,false);
  }
  public ManagedClusterSetBindingBuilder(ManagedClusterSetBinding instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ManagedClusterSetBinding());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
    }
    this.validationEnabled = validationEnabled; 
  }
  ManagedClusterSetBindingFluent<?> fluent;
  Boolean validationEnabled;
  public ManagedClusterSetBinding build() {
    ManagedClusterSetBinding buildable = new ManagedClusterSetBinding(fluent.getApiVersion(),fluent.getKind(),fluent.buildMetadata(),fluent.buildSpec());
    return buildable;
  }
  
}
